#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

class IDevices(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/devices'

	def listWiped (self):
		postUri = "/_listWiped";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.device.api.Device import Device
		from netbluemind.device.api.Device import __DeviceSerDer__
		return self.handleResult__(serder.ListSerDer(__DeviceSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

class IInstallation(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/system/installation'

	def getSystemState (self):
		postUri = "/state";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.system.api.SystemState import SystemState
		from netbluemind.system.api.SystemState import __SystemStateSerDer__
		return self.handleResult__(__SystemStateSerDer__(), response)
	def removeSubscription (self):
		postUri = "/subscription";
		data = None
		queryParams = {  };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def runningMode (self):
		postUri = "/state/_maintenance";
		data = None
		queryParams = {  };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def markSchemaAsUpgraded (self):
		postUri = "/version";
		data = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def upgradeStatus (self):
		postUri = "/_upgrade";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.system.api.UpgradeStatus import UpgradeStatus
		from netbluemind.system.api.UpgradeStatus import __UpgradeStatusSerDer__
		return self.handleResult__(__UpgradeStatusSerDer__(), response)
	def getInfos (self):
		postUri = "/_infos";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.system.api.PublicInfos import PublicInfos
		from netbluemind.system.api.PublicInfos import __PublicInfosSerDer__
		return self.handleResult__(__PublicInfosSerDer__(), response)
	def resetIndexes (self):
		postUri = "/_resetIndexes";
		data = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def deleteLogo (self):
		postUri = "/logo";
		data = None
		queryParams = {  };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def getVersion (self):
		postUri = "/version";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.system.api.InstallationVersion import InstallationVersion
		from netbluemind.system.api.InstallationVersion import __InstallationVersionSerDer__
		return self.handleResult__(__InstallationVersionSerDer__(), response)
	def setLogo (self, logo ):
		postUri = "/logo";
		data = None
		data = serder.ByteArraySerDer.encode(logo)

		queryParams = {   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def getLogo (self):
		postUri = "/logo";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.system.api.CustomLogo import CustomLogo
		from netbluemind.system.api.CustomLogo import __CustomLogoSerDer__
		return self.handleResult__(__CustomLogoSerDer__(), response)
	def upgrade (self):
		postUri = "/_upgrade";
		data = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def updateSubscription (self, licence ):
		postUri = "/subscription";
		data = None
		data = serder.STRING.encode(licence)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def getSubscriptionInformations (self):
		postUri = "/subscription";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.system.api.SubscriptionInformations import SubscriptionInformations
		from netbluemind.system.api.SubscriptionInformations import __SubscriptionInformationsSerDer__
		return self.handleResult__(__SubscriptionInformationsSerDer__(), response)
	def initialize (self):
		postUri = "/_initialize";
		data = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def maintenanceMode (self):
		postUri = "/state/_maintenance";
		data = None
		queryParams = {  };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def partialUpgrade (self, from_ , to ):
		postUri = "/_partialUpgrade";
		data = None
		queryParams = {  'from': from_  , 'to': to   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ICalendarElementOrganizer :
	def __init__( self):
		self.uri = None
		self.commonName = None
		self.mailto = None
		self.dir = None
		pass

class __ICalendarElementOrganizerSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = ICalendarElementOrganizer()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		uriValue = value['uri']
		instance.uri = serder.STRING.parse(uriValue)
		commonNameValue = value['commonName']
		instance.commonName = serder.STRING.parse(commonNameValue)
		mailtoValue = value['mailto']
		instance.mailto = serder.STRING.parse(mailtoValue)
		dirValue = value['dir']
		instance.dir = serder.STRING.parse(dirValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		uriValue = value.uri
		instance["uri"] = serder.STRING.encode(uriValue)
		commonNameValue = value.commonName
		instance["commonName"] = serder.STRING.encode(commonNameValue)
		mailtoValue = value.mailto
		instance["mailto"] = serder.STRING.encode(mailtoValue)
		dirValue = value.dir
		instance["dir"] = serder.STRING.encode(dirValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DomainTemplateKind :
	def __init__( self):
		self.description = None
		self.tags = None
		self.id = None
		pass

class __DomainTemplateKindSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = DomainTemplateKind()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.system.api.DomainTemplateDescription import DomainTemplateDescription
		from netbluemind.system.api.DomainTemplateDescription import __DomainTemplateDescriptionSerDer__
		descriptionValue = value['description']
		instance.description = __DomainTemplateDescriptionSerDer__().parse(descriptionValue)
		from netbluemind.system.api.DomainTemplateTag import DomainTemplateTag
		from netbluemind.system.api.DomainTemplateTag import __DomainTemplateTagSerDer__
		tagsValue = value['tags']
		instance.tags = serder.ListSerDer(__DomainTemplateTagSerDer__()).parse(tagsValue)
		idValue = value['id']
		instance.id = serder.STRING.parse(idValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.system.api.DomainTemplateDescription import DomainTemplateDescription
		from netbluemind.system.api.DomainTemplateDescription import __DomainTemplateDescriptionSerDer__
		descriptionValue = value.description
		instance["description"] = __DomainTemplateDescriptionSerDer__().encode(descriptionValue)
		from netbluemind.system.api.DomainTemplateTag import DomainTemplateTag
		from netbluemind.system.api.DomainTemplateTag import __DomainTemplateTagSerDer__
		tagsValue = value.tags
		instance["tags"] = serder.ListSerDer(__DomainTemplateTagSerDer__()).encode(tagsValue)
		idValue = value.id
		instance["id"] = serder.STRING.encode(idValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

class IAddressBooksMgmt(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/mgmt/addressbooks'

	def backup (self, containerUid , since ):
		postUri = "/{containerUid}/_backupstream";
		data = None
		postUri = postUri.replace("{containerUid}",containerUid);
		queryParams = {   'since': since   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(serder.STREAM, response)
	def reindexDomain (self, domain ):
		postUri = "/_reindexDomain";
		data = None
		queryParams = {  'domain': domain   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def reindex (self, containerUid ):
		postUri = "/{containerUid}/_reindex";
		data = None
		postUri = postUri.replace("{containerUid}",containerUid);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def restore (self, containerUid , restoreStream , reset ):
		postUri = "/{containerUid}/_restorestream";
		data = None
		postUri = postUri.replace("{containerUid}",containerUid);
		data = serder.STREAM.encode(restoreStream)

		queryParams = {    'reset': reset   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def update (self, containerUid , descriptor ):
		postUri = "/{containerUid}";
		data = None
		postUri = postUri.replace("{containerUid}",containerUid);
		from netbluemind.addressbook.api.AddressBookDescriptor import AddressBookDescriptor
		from netbluemind.addressbook.api.AddressBookDescriptor import __AddressBookDescriptorSerDer__
		data = __AddressBookDescriptorSerDer__().encode(descriptor)

		queryParams = {    };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def reindexAll (self):
		postUri = "/_reindex";
		data = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def delete (self, containerUid ):
		postUri = "/{containerUid}";
		data = None
		postUri = postUri.replace("{containerUid}",containerUid);
		queryParams = {   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def getComplete (self, containerUid ):
		postUri = "/{containerUid}";
		data = None
		postUri = postUri.replace("{containerUid}",containerUid);
		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.addressbook.api.AddressBookDescriptor import AddressBookDescriptor
		from netbluemind.addressbook.api.AddressBookDescriptor import __AddressBookDescriptorSerDer__
		return self.handleResult__(__AddressBookDescriptorSerDer__(), response)
	def create (self, containerUid , descriptor , isDefault ):
		postUri = "/{containerUid}";
		data = None
		postUri = postUri.replace("{containerUid}",containerUid);
		from netbluemind.addressbook.api.AddressBookDescriptor import AddressBookDescriptor
		from netbluemind.addressbook.api.AddressBookDescriptor import __AddressBookDescriptorSerDer__
		data = __AddressBookDescriptorSerDer__().encode(descriptor)

		queryParams = {    'isDefault': isDefault   };

		response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DirEntry :
	def __init__( self):
		self.kind = None
		self.path = None
		self.displayName = None
		self.entryUid = None
		self.email = None
		self.hidden = None
		self.system = None
		self.archived = None
		self.emails = None
		self.orgUnitUid = None
		self.orgUnitPath = None
		pass

class __DirEntrySerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = DirEntry()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		kindValue = value['kind']
		instance.kind = __DirEntryKindSerDer__().parse(kindValue)
		pathValue = value['path']
		instance.path = serder.STRING.parse(pathValue)
		displayNameValue = value['displayName']
		instance.displayName = serder.STRING.parse(displayNameValue)
		entryUidValue = value['entryUid']
		instance.entryUid = serder.STRING.parse(entryUidValue)
		emailValue = value['email']
		instance.email = serder.STRING.parse(emailValue)
		hiddenValue = value['hidden']
		instance.hidden = serder.BOOLEAN.parse(hiddenValue)
		systemValue = value['system']
		instance.system = serder.BOOLEAN.parse(systemValue)
		archivedValue = value['archived']
		instance.archived = serder.BOOLEAN.parse(archivedValue)
		from netbluemind.core.api.Email import Email
		from netbluemind.core.api.Email import __EmailSerDer__
		emailsValue = value['emails']
		instance.emails = serder.ListSerDer(__EmailSerDer__()).parse(emailsValue)
		orgUnitUidValue = value['orgUnitUid']
		instance.orgUnitUid = serder.STRING.parse(orgUnitUidValue)
		from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
		from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
		orgUnitPathValue = value['orgUnitPath']
		instance.orgUnitPath = __OrgUnitPathSerDer__().parse(orgUnitPathValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		from netbluemind.directory.api.DirEntryKind import DirEntryKind
		from netbluemind.directory.api.DirEntryKind import __DirEntryKindSerDer__
		kindValue = value.kind
		instance["kind"] = __DirEntryKindSerDer__().encode(kindValue)
		pathValue = value.path
		instance["path"] = serder.STRING.encode(pathValue)
		displayNameValue = value.displayName
		instance["displayName"] = serder.STRING.encode(displayNameValue)
		entryUidValue = value.entryUid
		instance["entryUid"] = serder.STRING.encode(entryUidValue)
		emailValue = value.email
		instance["email"] = serder.STRING.encode(emailValue)
		hiddenValue = value.hidden
		instance["hidden"] = serder.BOOLEAN.encode(hiddenValue)
		systemValue = value.system
		instance["system"] = serder.BOOLEAN.encode(systemValue)
		archivedValue = value.archived
		instance["archived"] = serder.BOOLEAN.encode(archivedValue)
		from netbluemind.core.api.Email import Email
		from netbluemind.core.api.Email import __EmailSerDer__
		emailsValue = value.emails
		instance["emails"] = serder.ListSerDer(__EmailSerDer__()).encode(emailsValue)
		orgUnitUidValue = value.orgUnitUid
		instance["orgUnitUid"] = serder.STRING.encode(orgUnitUidValue)
		from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
		from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
		orgUnitPathValue = value.orgUnitPath
		instance["orgUnitPath"] = __OrgUnitPathSerDer__().encode(orgUnitPathValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class Account :
	def __init__( self):
		self.userUid = None
		self.device = None
		pass

class __AccountSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = Account()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		userUidValue = value['userUid']
		instance.userUid = serder.STRING.parse(userUidValue)
		deviceValue = value['device']
		instance.device = serder.STRING.parse(deviceValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		userUidValue = value.userUid
		instance["userUid"] = serder.STRING.encode(userUidValue)
		deviceValue = value.device
		instance["device"] = serder.STRING.encode(deviceValue)
		return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

class IDataProtect(BaseEndpoint):
	def __init__(self, apiKey, url ):
		self.url = url
		self.apiKey = apiKey
		self.base = url +'/dataprotect'

	def saveAll (self):
		postUri = "/_backup";
		data = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def getContent (self, partGen ):
		postUri = "/_content/{partGen}";
		data = None
		postUri = postUri.replace("{partGen}",partGen);
		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def run (self, restoreDefinition ):
		postUri = "/restore";
		data = None
		from netbluemind.dataprotect.api.RestoreDefinition import RestoreDefinition
		from netbluemind.dataprotect.api.RestoreDefinition import __RestoreDefinitionSerDer__
		data = __RestoreDefinitionSerDer__().encode(restoreDefinition)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def getRestoreCapabilitiesByTags (self, tags ):
		postUri = "/restore/_capabilities_by_tags";
		data = None
		data = serder.ListSerDer(serder.STRING).encode(tags)

		queryParams = {   };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
		from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
		return self.handleResult__(serder.ListSerDer(__RestoreOperationSerDer__()), response)
	def installFromGeneration (self, generationId ):
		postUri = "/_install";
		data = None
		queryParams = {  'generationId': generationId   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def forget (self, generationId ):
		postUri = "/generations";
		data = None
		queryParams = {  'generationId': generationId   };

		response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.core.task.api.TaskRef import TaskRef
		from netbluemind.core.task.api.TaskRef import __TaskRefSerDer__
		return self.handleResult__(__TaskRefSerDer__(), response)
	def getRestoreCapabilities (self):
		postUri = "/restore/_capabilities";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.dataprotect.api.RestoreOperation import RestoreOperation
		from netbluemind.dataprotect.api.RestoreOperation import __RestoreOperationSerDer__
		return self.handleResult__(serder.ListSerDer(__RestoreOperationSerDer__()), response)
	def getRetentionPolicy (self):
		postUri = "/policy";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.dataprotect.api.RetentionPolicy import RetentionPolicy
		from netbluemind.dataprotect.api.RetentionPolicy import __RetentionPolicySerDer__
		return self.handleResult__(__RetentionPolicySerDer__(), response)
	def updatePolicy (self, rp ):
		postUri = "/policy";
		data = None
		from netbluemind.dataprotect.api.RetentionPolicy import RetentionPolicy
		from netbluemind.dataprotect.api.RetentionPolicy import __RetentionPolicySerDer__
		data = __RetentionPolicySerDer__().encode(rp)

		queryParams = {   };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)
	def getAvailableGenerations (self):
		postUri = "/generations";
		data = None
		queryParams = {  };

		response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		from netbluemind.dataprotect.api.DataProtectGeneration import DataProtectGeneration
		from netbluemind.dataprotect.api.DataProtectGeneration import __DataProtectGenerationSerDer__
		return self.handleResult__(serder.ListSerDer(__DataProtectGenerationSerDer__()), response)
	def syncWithFilesystem (self):
		postUri = "/_syncfs";
		data = None
		queryParams = {  };

		response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json'}, data = json.dumps(data));
		return self.handleResult__(None, response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class OrgUnit :
	def __init__( self):
		self.name = None
		self.parentUid = None
		pass

class __OrgUnitSerDer__:
	def __init__( self ):
		pass

	def parse(self, value):
		if(value == None):
			return None
		instance = OrgUnit()

		self.parseInternal(value, instance)
		return instance

	def parseInternal(self, value, instance):
		nameValue = value['name']
		instance.name = serder.STRING.parse(nameValue)
		parentUidValue = value['parentUid']
		instance.parentUid = serder.STRING.parse(parentUidValue)
		return instance

	def encode(self, value):
		if(value == None):
			return None
		instance = dict()
		self.encodeInternal(value,instance)
		return instance

	def encodeInternal(self, value, instance):

		nameValue = value.name
		instance["name"] = serder.STRING.encode(nameValue)
		parentUidValue = value.parentUid
		instance["parentUid"] = serder.STRING.encode(parentUidValue)
		return instance

